📝 Changelog
+++++++++++++

.. _unreleased:

Unreleased
==========

✨ Added
--------

* Added first version of the tbx cli tool with support for managing github workflows

🔧 Changed
----------

* Changed autogenerated comment in version.py for better clarity
* Updated dependencies
* Updated github issue templates

.. _changelog-0.4.0:

0.4.0 - 2023-04-19
==================

✨ Added
--------
* Added support for metrics
    - Added nox metrics task :code:`nox -s report`
    - Added GitHub workflow which generates and reports the metrics
    - Added metrics workflow call invocation to standard workflows
        * ci
        * ci-cd
        * pr-merge

🔧 Changed
----------
* Updated dependencies

🗑 Removed
----------
* Removed :code:`scriv` support

.. _changelog-0.3.0:

0.3.0 - 2022-12-21
==================

✨ Added
--------
* Added support for custom path filters to config object

🔧 Changed
----------
* Updated dependencies

.. _changelog-0.2.0:

0.2.0 — 2022-12-20
==================

✨ Added
--------
* Added basic templates for workflow and config files
* Added additional Project metadata

🔧 Changed
----------
* Updated dependencies
* Migrate project to exasol organization

📚 Documentation
----------------
* Updated workflow documentation


0.1.0 — 2022-11-25
==================

✨ Initial release
